@@ -1,5 +1,5 @@
 """Top-level package for Bayesian estimation of means"""
 
 __author__ = """Oliver Chipperfield"""
-__email__ = 'omc0dev@gmail.com'
-__version__ = '0.1.2'
+__email__ = "omc0dev@gmail.com"
+__version__ = "0.9.0"
